/* Create object on Desktop */

/***********************************************************************/
/*                                                                     */
/* This REXX script will create "PianoPad" WPS object (class "EPAD")   */
/* on your desktop. You can put it whereever you want later.           */
/* You can also specify your object name as first parameter and        */
/* ObjectID, as second parameter. When omitted, defaults will be used. */
/*                                                                     */
/***********************************************************************/

/***********************************************************************/
/*                                                                     */
/* ADDITIONAL_SETUP='ADDITIONAL SETUP STRING'                          */
/*                                                                     */
/* You can add your own setup into this variable to add your own setup */
/* to the object, created by default. This is useful, if you want      */
/* to create PianoPad objects on a lot of machines with, filled with   */
/* your own contents and with your own settings.                       */
/* Below you will find an example of a setup string to create PianoPad */
/* object, which contains:                                             */
/* 1. "OS/2 Sytem" folder                                              */
/* 2. "Assistance Center" folder with a drawer attached to it.         */
/*    The drawer contains "Hardware manager" object                    */
/* 3. Programs folder with dynamic drawer attached to it               */
/* 4. Shredder                                                         */
/*                                                                     */
/* All the settings are default but, "Auto-hide" feature is "ON",      */
/* "No drawers" is "OFF" and "Icon size" is "LARGE"                    */
/*                                                                     */
/***********************************************************************/

ADDITIONAL_SETUP=''
/* Example of using ADDITIONAL_SETUP variable.                        */
/* Uncomment the line below and comment the line above to make this   */
/* script create PianoPad object with different settings and contents */
/*
ADDITIONAL_SETUP='FPOBJECTS=<WP_OS2SYS>,<WP_ASSISTANCE>,<WP_PROGRAMSFOLDER>,<WP_SHRED>;DRAWEROBJECTS=2,<WP_HWMGR>;EPSETDYNAMIC=NO,NO,YES,NO;EPICONSIZE=LARGE;EPAUTOHIDE=YES;EPNODRAWERS=NO'
*/

   Call RxFuncAdd 'SysLoadFuncs', 'REXXUTIL', 'SysLoadFuncs';
   Call SysLoadFuncs;

   PARSE ARG ARGUMENTS

   PARSE VALUE ARGUMENTS WITH OBJECT_NAME THE_REST
   PARSE VALUE OBJECT_NAME WITH '"' OBJECT_NAME1 '"' XXX

   IF OBJECT_NAME1<>'' THEN
      OBJECT_NAME=OBJECT_NAME1

   IF OBJECT_NAME='' THEN
   DO
      OBJECT_NAME='PianoPad'
      SAY 'Usage:'
      SAY 'CREATE.CMD [OBJECT_NAME [OBJECT_ID]]'
      SAY 'If OBJECT_NAME omitted, "PianoPad" used by default.'
      SAY 'If OBJECT_ID omitted, "<PIANOPAD>" used by default.'
      SAY 'Example:'
      SAY 'CREATE.CMD PianoPad "<PIANOPAD>"'
   END

   PARSE VALUE THE_REST WITH OBJECT_ID THE_REST
   PARSE VALUE OBJECT_ID WITH '"' OBJECT_ID1 '"' XXX

   IF OBJECT_ID1<>'' THEN
      OBJECT_ID=OBJECT_ID1

   IF OBJECT_ID1='' THEN
      OBJECT_ID='<PIANOPAD>'

   SAY ''
   SAY 'You are about to create a new PianoPad object on the desktop.'
   SAY 'OBJECT NAME: '||OBJECT_NAME
   SAY 'OBJECT ID: '||OBJECT_ID
   rc=SysSetObjectData(OBJECT_ID,";")
   IF rc THEN
   DO
      SAY 'The object is exists already. It will be replaced with a new object!'
      SAY 'Are You sure? (Y/N)'
      PULL ANSWER
      IF LEFT(ANSWER, 1)<>'Y' THEN
      DO
         SAY 'Object creation cancelled.'
         EXIT
      END
   END

   rc=SysCreateObject('EPAD', OBJECT_NAME, '<WP_DESKTOP>', 'OBJECTID='||OBJECT_ID||';'||ADDITIONAL_SETUP||';','replace');

   IF rc <> 1 THEN
      Say  "PIANOPAD: could not create object on the Desktop, rc="rc".";
   ELSE
      Say  "PIANOPAD: object created successfuly!";
